@@ -51,6 +51,8 @@ GLIBTOP_SUID_PROC_SEGMENT +
 GLIBTOP_SUID_PROC_ARGS +
 GLIBTOP_SUID_PROC_MAP +
 GLIBTOP_SUID_NETLOAD +
+GLIBTOP_SUID_NETLIST +
+GLIBTOP_SUID_PROC_WD +
 GLIBTOP_SUID_PPP;
 
 #include <fcntl.h>
